@@ -1,6 +1,6 @@
 from .activation import Activation
 from .condition import Condition
 from .condition import HyperrectangleCondition
-from .rule import Rule
+from .rule import Rule, RegressionRule, ClassificationRule
 from .ruleset import RuleSet
 from .utils.rule_utils import extract_rules_from_tree
