@@ -138,6 +138,15 @@ class Activation(ABC):
                 f" {type(activation)}."
             )
 
+    def delete(self):
+        """Deletes the activation vector's data, either by deleting the local file or by calling del on self.data"""
+        if self.data_format == "file":
+            if self.data.isfile():
+                self.data.unlink()
+        else:
+            del self.data
+            self.data = None
+
     def _write(self, value: np.ndarray, name: str):
 
         logger.debug(f"Activation vector is raw, store it in a file")
