@@ -40,6 +40,11 @@ class Rule(ABC):
     def __add__(self, other: "Rule") -> "Rule":
         return NotImplemented("Can not add rules (seen as 'logical OR'). you can use logical AND however.")
 
+    def del_activation(self):
+        """Deletes the activation vector's data, but not the object itself, so any computed attribute will remain
+        available"""
+        self._activation.delete()
+
     @property
     def condition(self) -> Condition:
         return copy(self._condition)
